@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use Carp;
 
-use version; our $VERSION = qv('0.0.2');
+use version; our $VERSION = qv('0.0.3');
 
 # Other recommended modules (uncomment to use):
 #  use IO::Prompt;
@@ -27,7 +27,7 @@ sub new {
   $self->{start_url} = 'http://www2.nuis.co.jp/kzz80011.htm';
   $mech->agent_alias( 'Windows IE 6' );
   $self->{mech} = $mech;
-
+  $self->{user_agent} = __PACKAGE__;
   return bless $self, $class;
 }
  
@@ -101,6 +101,7 @@ sub _request {
     if ( ( exists $item2->{shop} ) && !( $item2->{status} =~ m/配達完了済/ ) ) {
       $item2->{status} = "$item2->{shop} $item2->{status}";
     }
+    $item2->{user_agent} = $self->{user_agent};
     push @$res2, $item2;
   }
   $res->{results} = $res2;
